<?php

use Behat\Behat\Context\Context;
use Behat\Behat\Hook\Scope\AfterStepScope;
use Behat\Gherkin\Node\PyStringNode;
use Behat\Gherkin\Node\TableNode;
use \Behat\MinkExtension\Context\MinkContext;
use \Behat\Mink\Element\NodeElement;

/**
 * Defines application features from the specific context.
 */
class FeatureContext extends MinkContext implements Context
{
    /**
     * Initializes context.
     *
     * Every scenario gets its own context instance.
     * You can also pass arbitrary arguments to the
     * context constructor through behat.yml.
     */
    public function __construct()
    {
    }

    /**
     * @BeforeScenario
     */
    public function beforeScenarioResize()
    {
        if ($this->getSession()->getDriver() instanceof \Behat\Mink\Driver\Selenium2Driver)
        {
            $this->getSession()->resizeWindow(1980, 1080, 'current');
        }
    }

    /**
     * @When I wait :seconds seconds
     *
     * @param mixed $seconds
     */
    public function iWaitSecondsForRedirect($seconds)
    {
        $this->getSession()->wait($seconds * 1000);
    }

    /**
     * @BeforeScenario @login
     */
    public function login()
    {
        $session = $this->getSession();
        $session->visit("https://build53.invorbereitung.de/login.php");

        $page = $session->getPage();
        $page->find("named", array("id", "username"))->setValue('cli');
        $page->find("named", array("id", "password"))->setValue('pccXKase');
        $page->find("named", array("button", "Login"))->click();
    }

    /**
     * @AfterStep
     */
    public function takeScreenShotAfterFailedStep(AfterStepScope $scope)
    {
        if (99 === $scope->getTestResult()->getResultCode())
        {
            try {
                $screenshotData = $this->getSession()->getDriver()->getScreenshot();
            } catch (\Behat\Mink\Exception\UnsupportedDriverActionException $e) {
            } catch (\Behat\Mink\Exception\DriverException $e) {
            }

            file_put_contents('/tmp/test_'.uniqid().'.png', $screenshotData);
        }
    }

    /**
     * Click some text
     * @When /^I click on the text "([^"]*)"$/
     *
     * @param string $text
     */
    public function iClickOnTheText($text)
    {
        $session = $this->getSession();
        $element = $session->getPage()->find(
            'xpath',
            $session->getSelectorsHandler()->selectorToXpath('xpath', '*//*[text()="'.$text.'"]')
        );

        if (null === $element) {
            throw new \InvalidArgumentException(sprintf('Cannot find text: "%s"', $text));
        }

        $element->click();
    }

    /**
     * @Then I click element :element
     *
     * @param $element
     */
    public function iClickElement($element)
    {
        $click = $this->getSession()->getPage()->find('named', ['id_or_name' , $element]);
        $click->click();
    }

    /**
     * @Then I focus on :field
     *
     * @param $field
     */
    public function iFocusOn($field)
    {
        $session = $this->getSession();
        $page = $session->getPage();
        $element = $page->find("named", ["id_or_name", $field]);

        if($element)
        {
            $element->focus();
        }

        $element = $page->find('xpath', '*//*[text()="' . $field . '"]');

        if($element)
        {
            $element->focus();
        }
    }

    /**
    * @Then I should see :count of the element :element
    *
    * @param int $count
    * @param string $element
    *
    * @return bool
    */
    public function iCountElements($count, $element)
    {
        $elements = $this->getSession()->getPage()->findAll('named',['id_or_name',$element]);

        return $count == count($elements);
    }
}
